@@ -1,9 +1,10 @@
 __all__ = ['is_isbn10', 'is_isbn13', 'clean', 'mask', 'info', 'meta',
            'to_isbn10', 'to_isbn13', 'get_isbnlike', 'notisbn',
-           'canonical', 'get_canonical_isbn', 'editions']
+           'canonical', 'get_canonical_isbn', 'editions', 'quiet_errors']
 
-__version__ = '2.0.2'
+__version__ = '2.0.3'
 
+from .exceptions import quiet_errors
 from .core import (is_isbn10, is_isbn13, to_isbn10, to_isbn13, clean,
     canonical, notisbn, get_isbnlike, get_canonical_isbn)
 from .ext import (mask, meta, info, editions)
