@@ -1,13 +1,17 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import logging
 from .webquery import WEBQuery
+from .exceptions import WPDataWrongShapeError
 
 UA = 'isbntools (gzip)'
 SERVICE_URL = 'https://www.googleapis.com/books/v1/volumes?q=isbn+%s&fields='\
     'items/volumeInfo(title,authors,publisher,publishedDate,language)'\
     '&maxResults=1'
 
+logger = logging.getLogger(__name__)
+
 
 class GOOBQuery(WEBQuery):
     """
@@ -27,24 +31,31 @@ class GOOBQuery(WEBQuery):
         """
         WEBQuery.check_data(self)
         data = WEBQuery.parse_data(self)
-        if 'items' in data:
+        try:
             # put the selected data in records
             records = data['items'][0]['volumeInfo']
-        else:
-            raise Exception('Error:no data for %s' % self.isbn)
+        except:
+            try:
+                extra = data['stat']
+                logger.debug('WPDataWrongShapeError for % with data %s' %
+                             (self.isbn, extra))
+            except:
+                pass
+            raise WPDataWrongShapeError(self.isbn)
 
         # canonical:
         # -> ISBN-13, Title, Authors, Publisher, Year, Language
         canonical = {}
+        canonical['ISBN-13'] = self.isbn
         canonical['Title'] = records['title'].replace(' :', ':')
-        canonical['Language'] = records['language']
+        canonical['Authors'] = repr(records.get('authors', []))
         canonical['Publisher'] = records.get('publisher', '')
         if 'publishedDate' in records and len(records['publishedDate']) >= 4:
             canonical['Year'] = records['publishedDate'][0:4]
         else:
             canonical['Year'] = ''
-        canonical['ISBN-13'] = self.isbn
-        canonical['Authors'] = repr(records.get('authors', []))
+        canonical['Language'] = records['language']
+
         return canonical
 
 
