@@ -11,15 +11,20 @@
 # `registry.py`, and *thats all*!
 
 
+import logging
 import re
 from .webquery import WEBQuery
 from .keys import keys
+from .exceptions import WPDataWrongShapeError
+
 
 UA = 'isbntools (gzip)'
 SERVICE_URL = 'http://isbndb.com/api/v2/json/%s/book/%s'
 
 PATT_YEAR = re.compile(r'\d{4}')
 
+logger = logging.getLogger(__name__)
+
 
 class ISBNDBQuery():
     """
@@ -39,29 +44,34 @@ class ISBNDBQuery():
         """
         WEBQuery.check_data(self)
         data = WEBQuery.parse_data(self)
-        if 'data' in data:
+        try:
             # put the selected data in records
             records = data['data'][0]
-        else:
-            raise Exception('Error:%s' % data['error'])
+        except:
+            try:
+                extra = data['error']
+                logger.debug('WPDataWrongShapeError for % with data %s' %
+                             (self.isbn, extra))
+            except:
+                pass
+            raise WPDataWrongShapeError(self.isbn)
 
         # canonical:
         # -> ISBN-13, Title, Authors, Publisher, Year, Language
         canonical = {}
-
-        canonical['Title'] = records['title']
-        canonical['Language'] = records['language'] or 'English'
-        canonical['Publisher'] = records['publisher_name']
         canonical['ISBN-13'] = self.isbn
         assert self.isbn == records['isbn13'], "isbn was mungled!"
+        canonical['Title'] = records['title']
+        authors = [a['name'] for a in records['author_data']]
+        canonical['Authors'] = repr(authors)
+        canonical['Publisher'] = records['publisher_name']
         canonical['Year'] = ''
         if 'edition_info' in records:
             match = re.search(PATT_YEAR, records['edition_info'])
             if match:
                 canonical['Year'] = match.group(0)
+        canonical['Language'] = records['language'] or 'English'
 
-        authors = [a['name'] for a in records['author_data']]
-        canonical['Authors'] = repr(authors)
         return canonical
 
 
