@@ -1,12 +1,17 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import logging
 from .webquery import WEBQuery
+from .exceptions import WPDataWrongShapeError
+
 
 UA = 'isbntools (gzip)'
 SERVICE_URL = 'http://xisbn.worldcat.org/webservices/xid/isbn/%s?'\
     'method=getMetadata&format=json&fl=*'
 
+logger = logging.getLogger(__name__)
+
 
 class WCATQuery(WEBQuery):
     """
@@ -26,22 +31,28 @@ class WCATQuery(WEBQuery):
         """
         WEBQuery.check_data(self)
         data = WEBQuery.parse_data(self)
-        if 'list' in data:
-            # put the selected data in records 
+        try:
+            # put the selected data in records
             records = data['list'][0]
-        else:
-            raise Exception('Error:%s' % data['stat'])
+        except:
+            try:
+                extra = data['stat']
+                logger.debug('WPDataWrongShapeError for % with data %s' %
+                             (self.isbn, extra))
+            except:
+                pass
+            raise WPDataWrongShapeError(self.isbn)
 
         # canonical:
         # -> ISBN-13, Title, Authors, Publisher, Year, Language
         canonical = {}
+        canonical['ISBN-13'] = self.isbn
         canonical['Title'] = records['title'].replace(' :', ':')
-        canonical['Language'] = records['lang']
+        canonical['Authors'] = '[%s]' % records.get('author', '')
         canonical['Publisher'] = records['publisher']
         canonical['Year'] = records['year']
-        canonical['ISBN-13'] = self.isbn
-        canonical['Authors'] = '[%s]' % records.get('author', '')
-        
+        canonical['Language'] = records['lang']
+
         return canonical
 
 
