@@ -1,9 +1,13 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-
+import logging
 from ast import literal_eval
 from .webquery import WEBQuery
+from .exceptions import WPDataWrongShapeError
+
+logger = logging.getLogger(__name__)
+
 
 UA = 'isbntools (gzip)'
 SERVICE_URL = 'http://xisbn.worldcat.org/webservices/xid/isbn/%s?'\
@@ -28,12 +32,17 @@ class WCATEdQuery(WEBQuery):
         """
         WEBQuery.check_data(self)
         data = WEBQuery.parse_data(self, parser=literal_eval)
-
-        if 'list' in data:
+        try:
             # put the selected data in records
             records = [ib['isbn'][0] for ib in data['list']]
-        else:
-            raise Exception('Error:%s' % data['stat'])
+        except:
+            try:
+                extra = data['stat']
+                logger.debug('WPDataWrongShapeError for % with data %s' %
+                             (self.isbn, extra))
+            except:
+                pass
+            raise WPDataWrongShapeError(self.isbn)
         return records
 
 
