@@ -2,13 +2,17 @@
 # -*- coding: utf-8 -*-
 
 
+import logging
 import urllib
 import urllib2
 import gzip
 from StringIO import StringIO
+from .exceptions import WSHTTPError, WSURLError
 
 UA = 'webservice (gzip)'
 
+logger = logging.getLogger(__name__)
+
 
 class WEBQuery(object):
     """
@@ -30,9 +34,13 @@ class WEBQuery(object):
         try:
             self.response = urllib2.urlopen(request)
         except urllib2.HTTPError as e:
-            raise Exception('Error:%s' % e.code)
+            logger.critical('WSHTTPError for %s with code %s' %
+                            (url, e.code))
+            raise WSHTTPError(e.code)
         except urllib2.URLError as e:
-            raise Exception('Error:%s' % e.reason)
+            logger.critical('WSURLError for %s with  reason %s' %
+                            (url, e.reason))
+            raise WSURLError(e.reason)
 
     def data(self):
         """
